@@ -2,7 +2,7 @@
 /*
  * Kanatest
  *
- * Copyright (C) 2001 Tomasz Mka
+ * Copyright (C) 2001-2004, 2006 Tomasz Mka <pasp@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,34 +19,36 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifndef _GUI_H
+#define _GUI_H
+
 #include <gtk/gtk.h>
 #include <time.h>
 
-#define		buffer_size		256
+#define		BUFFER_SIZE		256
 
 typedef enum {
 	B_STATS = 0,
 	B_ABOUT,
+	B_OPTIONS,
+	B_CHART,
 	B_STOP,
 	B_START
 } bhandler;
 
-extern 			gint					stop_flag;
-extern 			GtkWidget				*rm_entry;
+extern 			GtkWidget				*romaji_entry;
 extern 			GtkWidget				*stop_button;
-extern			time_t					timer_int_l;
+
+extern 			gint					stop_flag;
+extern			time_t					start_time;
 
 void			gui_create_window		(void);
-void			gui_stat_create_window	(gint mode);
-void			gui_about_create_window	(void);
-void			gui_set_label			(gchar *text);
 void			gui_disable_test		(void);
 void			gui_disable_start		(void);
-void			gui_put_sign			(gint number, gint mode);
+void			gui_display_kana		(gint number, gint mode);
 void			gui_set_progress		(void);
-gchar*			input_clean				(gchar *word);
-gint			rm_key_press 			(GtkWidget *widget, GdkEventKey *event, gpointer data);
-GtkWidget*		gui_stock_label_button	(gchar *blabel, const gchar *bstock);
 void			gui_set_widgets_status	(gint mode);
+GtkWidget*		gui_stock_label_button	(gchar *blabel, const gchar *bstock);
 
+#endif /* _GUI_H */
 
