@@ -2,7 +2,7 @@
 /*
  * Kanatest
  *
- * Copyright (C) 2001 Tomasz Mka
+ * Copyright (C) 2001-2004, 2006 Tomasz Mka <pasp@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,15 +19,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifndef _MAIN_H
+#define _MAIN_H
+
 typedef enum {
-	HIRAGANA = 0,
-	KATAKANA,
-	MIXED,
-	ROMAJI,
-	STAT
+    ROMAJI = 0,     /* don't change order ! */
+    HIRAGANA,
+    KATAKANA,
+    MIXED,
+    STAT
 } tmode;
 
-extern 		gint				test_mode;
-extern 		struct jpprefs		config;
+#endif /* _MAIN_H */
 
 
